@@ -33,6 +33,8 @@ class DetectSequence(Base):
                         'general': {
                             # sequence of models you want to run for every specified frame
                             'model_sequence': 'object,face,alpr' ,
+                            # If 'yes', will not use portalocks
+                            'disable_locks':'no',
 
                         },
                     
@@ -140,6 +142,7 @@ class DetectSequence(Base):
                     self.models[seq] = []
                     for obj_seq in self.ml_options.get(seq,{}).get('sequence'):
                         try:
+                            obj_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
                             self.logger.Debug (2,'Initializing model  type:{} with options:{}'.format(seq,obj_seq ))
                             self.models[seq].append(ObjectDetect.Object(options=obj_seq, logger=self.logger))
                         except Exception as e:
@@ -150,6 +153,7 @@ class DetectSequence(Base):
                     self.models[seq] = []
                     for face_seq in self.ml_options.get(seq,{}).get('sequence'):
                         try:
+                            face_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
                             self.models[seq].append(FaceDetect.Face(options=face_seq, logger=self.logger))
                         except Exception as e:
                             self.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
@@ -158,7 +162,9 @@ class DetectSequence(Base):
                 elif seq == 'alpr':
                     self.models[seq] = []
                     for alpr_seq in self.ml_options.get(seq,{}).get('sequence'):
+                        
                         try:
+                            alpr_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
                             self.models[seq].append(AlprDetect.Alpr(options=alpr_seq, logger=self.logger))
                         except Exception as e:
                             self.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
@@ -239,8 +245,17 @@ class DetectSequence(Base):
                         r = re.compile(p['pattern'])
                         match = list(filter(r.match, label))
                     else:
-                        match_pattern = self.ml_options.get(seq,{}).get('general',{}).get('pattern', '.*')
-                        self.logger.Debug(3,'Using global match pattern: {}'.format(match_pattern))
+                        '''
+                        self.logger.Debug (1,'**********************************')
+                        self.logger.Debug (1,'{}'.format(self.ml_overrides))
+                        self.logger.Debug (1,'**********************************')
+                        '''
+                        if self.ml_overrides.get(seq,{}).get('pattern'):
+                            match_pattern = self.ml_overrides.get(seq,{}).get('pattern')
+                            self.logger.Debug(2,'Match pattern overridden to {} in ml_overrides'.format(match_pattern))
+                        else:
+                            match_pattern = self.ml_options.get(seq,{}).get('general',{}).get('pattern', '.*')
+                            self.logger.Debug(2,'Using global match pattern: {}'.format(match_pattern))
 
                         r = re.compile(match_pattern)
                         match = list(filter(r.match, label))
@@ -377,6 +392,9 @@ class DetectSequence(Base):
             # For each frame, loop across all models
             found = False
             for seq in self.model_sequence:
+                if seq not in self.ml_overrides.get('model_sequence',seq):
+                    g.logger.Debug (1, 'Skipping {} as it was overridden in ml_overrides'.format(seq))
+                    continue
                 self.logger.Debug(1,'============ Frame: {} Running {} model in sequence =================='.format(self.media.get_last_read_frame(),seq))
                 pre_existing_labels = self.ml_options.get(seq,{}).get('general',{}).get('pre_existing_labels')
                 if pre_existing_labels:
